AsyncProviderOverrideCompat<T> extension
Extension helpers for overriding async providers.
- on
Methods
-
overrideWith(
dynamic override) → ProviderOverride< AsyncValue< T> > -
Available on AsyncProvider<
Creates an override for this async provider using a compatible factory.T> , provided by the AsyncProviderOverrideCompat extension -
overrideWithBuild(
AsyncValue< T> builder(Ref<AsyncValue< ref, AsyncProvider<T> >T> notifier)) → ProviderOverride<AsyncValue< T> > -
Available on AsyncProvider<
Creates an override that can access the original notifier.T> , provided by the AsyncProviderOverrideCompat extension -
overrideWithValue(
AsyncValue< T> value) → ProviderOverride<AsyncValue< T> > -
Available on AsyncProvider<
Creates an override that always returnsT> , provided by the AsyncProviderOverrideCompat extensionvalue.