Call<R, State> class
abstract
Interface for executable mutation or run calls.
Constructors
- Call()
Properties
-
body
→ Future<
R> Function(Ref<State> ref) -
The body to execute within a Ref context.
no setter
- concurrency → Concurrency
-
Concurrency policy for this call.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
owner
→ ProviderBase<
State> -
The owner provider for this call.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
token
→ MutationToken<
R> ? -
Optional mutation token that enables tracking.
no setter
Methods
-
ensureOwner(
ProviderContainer container) → void - Ensures the owner is built before execution.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited