Concurrency enum


Mutation primitives + Concurrency

Concurrency policy for tracked mutations.

Inheritance
Available extensions

Values

concurrent → const Concurrency

Run concurrently (default).

queue → const Concurrency

Run sequentially in FIFO order.

restart → const Concurrency

Only the latest run is valid; previous runs are cancelled.

dropLatest → const Concurrency

Drop new calls while a run is active.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Concurrency>
A constant List of the values in this enum, in order of their declaration.