ErrorMutationState<T> class final

Error state for a mutation.

Inheritance

Constructors

ErrorMutationState(Object error, StackTrace stack)
Creates an error state with the thrown error and stack.

Properties

error Object
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack StackTrace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited