key property
ProviderKey
get
key
Creates a key from the provider type and args.
Implementation
ProviderKey get key =>
ProviderKey(runtimeType.toString(), _hashArgs(args ?? this));
Creates a key from the provider type and args.
ProviderKey get key =>
ProviderKey(runtimeType.toString(), _hashArgs(args ?? this));