ProviderKey class final


ProviderKey = (type + args)

Unique identifier for a provider based on its type and arguments.

Constructors

ProviderKey(String type, int argsHash)
Creates a key from a type name and argument hash.

Properties

argsHash int
final
hashCode int
Hash code for this key.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a debug-friendly string for this key.
override

Operators

operator ==(Object other) bool
Returns whether other represents the same provider identity.
override