ProviderObserver class abstract
Observer for provider lifecycle events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didAddProvider(
ProviderObserverContext context, Object? value) → void - Called when a provider is first added to the container.
-
didDisposeProvider(
ProviderObserverContext context) → void - Called when a provider is disposed.
-
didUpdateProvider(
ProviderObserverContext context, Object? previousValue, Object? newValue) → void - Called when a provider updates its value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
providerDidFail(
ProviderObserverContext context, Object error, StackTrace stackTrace) → void - Called when a provider throws while building or updating.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited