ProviderObserverContext class final

Context passed to ProviderObserver callbacks.

Constructors

ProviderObserverContext(ProviderBase provider)
Creates a context for the given provider.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider ProviderBase
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited