overrideWithBuild method
Creates an override that can access the original notifier.
Implementation
ProviderOverride<S> overrideWithBuild(
S Function(Ref<S> ref, P notifier) builder,
) {
return overrideWith((ref) => builder(ref, this));
}
Creates an override that can access the original notifier.
ProviderOverride<S> overrideWithBuild(
S Function(Ref<S> ref, P notifier) builder,
) {
return overrideWith((ref) => builder(ref, this));
}