ProviderSubscription<T> class final

Handle returned by ProviderContainer.listen for cancelling a subscription.

Constructors

ProviderSubscription(void _cancel())
Creates a subscription that calls _cancel when closed.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Cancels the subscription.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited