onDispose method
void
onDispose(
- void cb()
Registers a callback to run when the provider is disposed.
Implementation
void onDispose(void Function() cb) => _core.onDispose(cb);
Registers a callback to run when the provider is disposed.
void onDispose(void Function() cb) => _core.onDispose(cb);