MutationToken<T> class
final
Provider token that exposes mutation state via ref.watch(token).
- Inheritance
-
- Object
- ProviderBase<
MutationState< T> > - MutationToken
Constructors
- MutationToken({required ProviderBase owner, required Symbol symbol})
-
Creates a mutation token owned by
ownerand identified bysymbol.const
Properties
- args → Record?
-
Arguments used to define provider identity for families.
no setteroverride
- argument → Object?
-
Exposes args for Riverpod compatibility.
no setterinherited
- autoDispose → bool
-
Whether to auto-dispose when there are no listeners.
no setteroverride
- autoDisposeDelay → Duration
-
Delay before auto-disposal when unused.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → ProviderKey
-
Creates a key from the provider type and args.
no setterinherited
- name → String?
-
Optional debug name for this provider.
no setterinherited
- owner → ProviderBase
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → Symbol
-
final
Methods
-
initialState(
) → MutationState< T> - Creates the initial mutation state for this token.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a debug-friendly string for this provider.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited